import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AOPAShdADMciiJvqlzh/FMS3RiVPQa3uQmViy1sMUeCVTkj3EPluGAa+hDrajAHs+TLK/InVfSyauP+0CrJ5Eu4qCPXbgGWlCmeLlAmR2GhtxmzgQBoMAUsNbfbKD70Zg2aLxQge5HzvVVUTLK3EO7YWOBD8su21OV0tOmU1GGDmwYvI7r23gsCe9trh5bOJYNnKr3szK87+OrvPf8FRKKgrVwGjpUDwq0RDNmUlW6v3Vie/nUTlYjg8fcLWOWmykrZkf0fEH0y0offAGXpq/Ina+2vqGHeLqrsJy87EkhGN5Ydx40pnLJQ5NDQaLcldilvvhTVpfat+toAWe5wDCBLWZ11YRsA8NCtAugvZN7f6DckbAwxIgjl7P+IdTi8soVmTozFXoSMR6IC7PcAADJLSrmfruYTAAHEApAHAAA+LOOLscRn+wIAAAAABFla')))