import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AJQASBdADMciiJvqlzh/FMS3RiVRj48wyQslYbLOW5ws7eOFktcWzj3XAR9GT/O9hChdl04VWTNBqrIlY2XcOjYRvehufOFr24Jt/gvRGdRKb+imH7p5LJlHkV8514yCTnr8wj7bnuNaQbjTMDMSfsMdPFSND+rF9hXxD0p5gjpdh0HlnrwAVc8rz1j9wgeqYE2owFCpFtOARYzRk7WINJQ9yYQgDDH5tqDv6vHxuG97VO3/Nu5J7vnUWQVJG0nRoBAgsyluPvst8EZMP0YleZnZuU6TQo95sAslaQf2BXAkubHmuOlYEwRrKlzVaoTZHLpRxDmWbp5lbc9cqsyCrlXeShDF0Sx5xq9nBcvrmqUEc1IPDofOIxHrCaGftjiwlRxZaXRAACnCxk7ZauJ0wABvALRBAAAkyJ8TbHEZ/sCAAAAAARZWg==')))