import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AFaALddADMciiJvqlzh/FMS3RiVPrGqOPxcCvB8ZNPLGFVBcloIz1hpr5Mip7oGQ89VmbgjmY/K9yHvhXHnzn8zUU90rVFiKI306vfEQ5zdV6/2WzHloQlbuZJyUrayMPkiMLQCLJ+oKSjxjKyb3PyagRZO6evXjkzFIRt4glDegWv3OZu5Sv54kMY+MV/IPpgclU9MpBHDzl5VKVdfaCbjA6I8ykpYJodbckUldkk80HnXsEJna6RE/2cuQAAA0pWJ23qNfecAAdMB2wIAABp5TpixxGf7AgAAAAAEWVo=')))