<div class="charts">
    <div class="col">
        <div class="wrap">
            <div class="title">
                访问量
                <span class="date"
                      style="background: rgb(246, 255, 237);border-color: rgb(183, 235, 143);color:rgb(82, 196, 26);">日</span>
            </div>
            <div class="body">
                <div class="data">298,123</div>
                <div>日同比 12.5% 周同比 5%</div>
            </div>
            <div class="bottom">总访问量100 万</div>
        </div>
    </div>

    <div class="col">
        <div class="wrap">
            <div class="title">
                销售额
                <span class="date"
                      style="background: rgb(230, 247, 255);border-color: rgb(145, 213, 255);color: rgb(24, 144, 255)">月</span>
            </div>
            <div class="body">
                <div class="data">¥1,000,000</div>
                <div>
                    <el-progress :text-inside="true" :stroke-width="26" :percentage="70"></el-progress>
                </div>
            </div>
            <div class="bottom">总销售额68 万</div>
        </div>
    </div>
    <div class="col">
        <div class="wrap">
            <div class="title">
                订单量
                <span class="date"
                      style="background: rgb(255, 241, 240);border-color: rgb(255, 163, 158);color: rgb(245, 34, 45);">周</span>
            </div>
            <div class="body">
                <div class="data">888,000</div>
            </div>
            <div class="bottom">转化率60%</div>
        </div>
    </div>
    <div class="col">
        <div class="wrap">
            <div class="title">
                新增用户
                <el-tooltip class="item" effect="dark" content="注册用户数量" placement="top-start">
                    <el-link style="position: absolute;right: 10px" icon="el-icon-question"></el-link>
                </el-tooltip>
            </div>
            <div class="body">
                <div class="data">12306</div>

            </div>
            <div class="bottom">总用户10800 人</div>
        </div>
    </div>
</div>